@@ -2,7 +2,7 @@
 import logging
 
 from python_ishare.authentication import create_jwt, decode_jwt, x5c_b64_to_certificate
-from python_ishare.clients import CommonBaseClient, IShareSatelliteClient
+from python_ishare.clients import CommonBaseClient, ISHARESatelliteClient
 from python_ishare.verification import validate_client_assertion
 
 logging.getLogger(__name__).addHandler(logging.NullHandler())
